==> hibiscus.js-1.2.1.tgz: package/dialog/dialog.service.js <==
import { Injectable, ComponentFactoryResolver } from '@angular/core';
import { ModalService } from '../modal/modal.service';
import { AlertDialogComponent } from './alert-dialog.component';
import { ConfirmDialogComponent } from './confirm-dialog.component';
import { DomSanitizer } from '@angular/platform-browser';
import { PromptDialogComponent } from './prompt-dialog.component';
var DialogService = /** @class */ (function () {
    function DialogService(modalService, componentFactoryResolver, domSanitizer) {
        this.modalService = modalService;
        this.componentFactoryResolver = componentFactoryResolver;
        this.domSanitizer = domSanitizer;
    }
    DialogService.prototype.alert = function (dialogOptions) {
        if (dialogOptions.content && dialogOptions.html && (typeof dialogOptions.content === 'string')) {
            dialogOptions.content = this.domSanitizer.bypassSecurityTrustHtml(dialogOptions.content);
        }
        return this.modalService.open({
            component: AlertDialogComponent,
            componentFactoryResolver: this.componentFactoryResolver,
            resolve: dialogOptions,
            modalClass: dialogOptions.cssClass,
            injector: dialogOptions.injector,
            rootContainer: dialogOptions.rootContainer,
            backdrop: dialogOptions.backdrop,
            backdropClass: dialogOptions.backdropClass,
            modal: dialogOptions.modal,
            keyboard: dialogOptions.keyboard,
            animation: dialogOptions.animation
        });
    };
    DialogService.prototype.confirm = function (dialogOptions) {
        if (dialogOptions.content && dialogOptions.html && (typeof dialogOptions.content === 'string')) {
            dialogOptions.content = this.domSanitizer.bypassSecurityTrustHtml(dialogOptions.content);
        }
        return this.modalService.open({
            component: ConfirmDialogComponent,
            componentFactoryResolver: this.componentFactoryResolver,
            resolve: dialogOptions,
            modalClass: dialogOptions.cssClass,
            injector: dialogOptions.injector,
            rootContainer: dialogOptions.rootContainer,
            backdrop: dialogOptions.backdrop,
            backdropClass: dialogOptions.backdropClass,
            modal: dialogOptions.modal,
            keyboard: dialogOptions.keyboard,
            animation: dialogOptions.animation
        });
    };
    DialogService.prototype.prompt = function (dialogOptions) {
        return this.modalService.open({
            component: PromptDialogComponent,
            componentFactoryResolver: this.componentFactoryResolver,
            resolve: dialogOptions,
            modalClass: dialogOptions.cssClass,
            injector: dialogOptions.injector,
            rootContainer: dialogOptions.rootContainer,
            backdrop: dialogOptions.backdrop,
            backdropClass: dialogOptions.backdropClass,
            modal: dialogOptions.modal,
            keyboard: dialogOptions.keyboard,
            animation: dialogOptions.animation
        });
    };
    DialogService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    DialogService.ctorParameters = function () { return [
        { type: ModalService, },
        { type: ComponentFactoryResolver, },
        { type: DomSanitizer, },
    ]; };
    return DialogService;
}());
export { DialogService };

==> hibiscus.js-1.2.3.tgz: package/dialog/dialog.service.js <==
import { Injectable, ComponentFactoryResolver } from '@angular/core';
import { ModalService } from '../modal/modal.service';
import { AlertDialogComponent } from './alert-dialog.component';
import { ConfirmDialogComponent } from './confirm-dialog.component';
import { DomSanitizer } from '@angular/platform-browser';
import { PromptDialogComponent } from './prompt-dialog.component';
var DialogService = (function () {
    function DialogService(modalService, componentFactoryResolver, domSanitizer) {
        this.modalService = modalService;
        this.componentFactoryResolver = componentFactoryResolver;
        this.domSanitizer = domSanitizer;
    }
    DialogService.prototype.alert = function (dialogOptions) {
        if (dialogOptions.content && dialogOptions.html && (typeof dialogOptions.content === 'string')) {
            dialogOptions.content = this.domSanitizer.bypassSecurityTrustHtml(dialogOptions.content);
        }
        return this.modalService.open({
            component: AlertDialogComponent,
            componentFactoryResolver: this.componentFactoryResolver,
            resolve: dialogOptions,
            modalClass: dialogOptions.cssClass,
            injector: dialogOptions.injector,
            rootContainer: dialogOptions.rootContainer,
            backdrop: dialogOptions.backdrop,
            backdropClass: dialogOptions.backdropClass,
            modal: dialogOptions.modal,
            keyboard: dialogOptions.keyboard,
            animation: dialogOptions.animation
        });
    };
    DialogService.prototype.confirm = function (dialogOptions) {
        if (dialogOptions.content && dialogOptions.html && (typeof dialogOptions.content === 'string')) {
            dialogOptions.content = this.domSanitizer.bypassSecurityTrustHtml(dialogOptions.content);
        }
        return this.modalService.open({
            component: ConfirmDialogComponent,
            componentFactoryResolver: this.componentFactoryResolver,
            resolve: dialogOptions,
            modalClass: dialogOptions.cssClass,
            injector: dialogOptions.injector,
            rootContainer: dialogOptions.rootContainer,
            backdrop: dialogOptions.backdrop,
            backdropClass: dialogOptions.backdropClass,
            modal: dialogOptions.modal,
            keyboard: dialogOptions.keyboard,
            animation: dialogOptions.animation
        });
    };
    DialogService.prototype.prompt = function (dialogOptions) {
        return this.modalService.open({
            component: PromptDialogComponent,
            componentFactoryResolver: this.componentFactoryResolver,
            resolve: dialogOptions,
            modalClass: dialogOptions.cssClass,
            injector: dialogOptions.injector,
            rootContainer: dialogOptions.rootContainer,
            backdrop: dialogOptions.backdrop,
            backdropClass: dialogOptions.backdropClass,
            modal: dialogOptions.modal,
            keyboard: dialogOptions.keyboard,
            animation: dialogOptions.animation
        });
    };
    DialogService.decorators = [
        { type: Injectable },
    ];
    DialogService.ctorParameters = function () { return [
        { type: ModalService, },
        { type: ComponentFactoryResolver, },
        { type: DomSanitizer, },
    ]; };
    return DialogService;
}());
export { DialogService };
